@@ -2,10 +2,11 @@
 # :Project:   python-rapidjson -- Tracemalloc-based leaks tests
 # :Created:   dom 10 feb 2019 13:47:32 CET
 # :Author:    Lele Gaifax <lele@metapensiero.it>
-# :License:   GNU General Public License version 3 or later
+# :License:   MIT License
 # :Copyright: © 2019 Lele Gaifax
 #
 
+import io
 import datetime
 import gc
 import tracemalloc
@@ -28,7 +29,7 @@ def default(obj):
         return obj
 
 
-def test_memory_leaks():
+def test_object_hook_and_default():
     tracemalloc.start()
 
     data = []
@@ -50,6 +51,29 @@ def test_memory_leaks():
     top_stats = snapshot2.compare_to(snapshot1, 'lineno')
     tracemalloc.stop()
 
-    top_stats
+    for stat in top_stats[:10]:
+        assert stat.count_diff < 3
+
+
+def test_load():
+    tracemalloc.start()
+
+    snapshot1 = tracemalloc.take_snapshot().filter_traces((
+        tracemalloc.Filter(True, __file__),))
+
+    for _ in range(10):
+        content = io.StringIO('[' + ','.join('{"foo": "bar"}' for _ in range(100)) + ']')
+        rj.load(content, chunk_size=50)
+
+    del content
+    del _
+    gc.collect()
+
+    snapshot2 = tracemalloc.take_snapshot().filter_traces((
+        tracemalloc.Filter(True, __file__),))
+
+    top_stats = snapshot2.compare_to(snapshot1, 'lineno')
+    tracemalloc.stop()
+
     for stat in top_stats[:10]:
         assert stat.count_diff < 3
